This function lists all the datasets available on Malaria Cell Atlas Database.
Value
df A dataframe listing all the datasets available on MCA and URls that can be used with easyMCA() function.
This function lists all the datasets available on Malaria Cell Atlas Database.
df A dataframe listing all the datasets available on MCA and URls that can be used with easyMCA() function.