A convenience function to quickly fetch preconfigured table of Signal Peptide ranges, Pathways, Pubmed entries related to genes, Annotations and etc from database of your choice such as PlasmoDB, ToxoDB, PiroplasmaDB among other VEuPathDB pathogen databases.
Usage
getPreconfiguredTable(
org = NULL,
db = "plasmodb",
customField = "Y2hInteractions",
listtables = FALSE,
api_key = Sys.getenv("VEUPATHDB_API_KEY")
)Arguments
- org
Full name of organism of interest as specified in VEuPathDB. To find the exact name of the organism, use
listVeupathdbfunction.- db
Character Name of the database in which the organism is present. These can be one of the following: "toxodb","plasmodb","hostdb","amoebadb","cryptodb","fungidb","giardiadb","microsporidiadb","piroplasmadb","trichdb","tritrypdb".
- customField
Preconfigured table that you wish the fetch. Pass only one value at a time from the following: "GeneModelDump", "GeneTranscripts", "Alias", "GeneLinkouts", "GeneLocation", "PubMed", "OrthologsLite", "LowComplexity", "PdbSimilarities", "3dPreds", "AlphaFoldLinkouts", "ProteinProperties", "InterPro", "SignalP", "TMHMM", "ECNumbers", "ECNumbersInferred", "protein_length", "chromosome", "location_text", "sequence_id", "gene_ortholog_number", "gene_orthomcl_name", "gene_paralog_number", "MetabolicPathwaysMPMP", "MetabolicPathways", "CompoundsMetabolicPathways", "Y2hInteractions", "MassSpecDownload", "MassSpecMod", "Epitopes" etc. You can view list of 58 preconfigured tables across VEuPathDB databases using
getPreconfiguredTable(listtables = TRUE)- listtables
To get list of preconfigured tables that can be supplied as an argument to
customField.- api_key
Character. VEuPathDB API key used for authentication. By default, the value is obtained from the
VEUPATHDB_API_KEYenvironment variable.