Fetch Protein-protein interaction for given gene IDs from Hit Predict database
Source:R/searchHP.R
searchHP.RdThis function searches the Hitpredict database to retrieve the Experimental Protein-Protein Interaction data.
Arguments
- geneID
Single gene ID.
- taxid
Taxon ID of the organism of interest. Default: 36329. If taxon id of organism is not known set this to NULL.
- uniprotToGID
To convert Uniprot ID to gene ID. Set TRUE for Plasmodium geneIDs only.
- timeout
Seconds after which timeout must be considered.
- max_tries
Maximum retries to access the database.